@@ -14,7 +14,6 @@ from .util import NotProvided
 from .parser import (
     create_app_clients_parser,
     create_assets_parser,
-    create_batches_parser,
     create_datasets_parser,
     create_documents_parser,
     create_logs_parser,
@@ -29,14 +28,13 @@ from .parser import (
 
 
 def create_parser():
-    parser = argparse.ArgumentParser()
+    parser = argparse.ArgumentParser(formatter_class=argparse.ArgumentDefaultsHelpFormatter)
     parser.add_argument('--profile')
     parser.add_argument('--verbose', '-v', action='count', default=0)
     subparsers = parser.add_subparsers()
 
     create_app_clients_parser(subparsers)
     create_assets_parser(subparsers)
-    create_batches_parser(subparsers)
     create_datasets_parser(subparsers)
     create_documents_parser(subparsers)
     create_logs_parser(subparsers)
